"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.lookbehind = lookbehind;
var _encoder = require("../encoder/encoder");
var _elements = require("../utils/elements");
/**
 * Positive lookbehind assertion.
 *
 * A positive lookbehind assertion is a zero-width assertion that matches a group of characters only if it is preceded by a specific group of characters.
 *
 * @example
 * ```ts
 * lookbehind("a");
 * // /(?<=a)/
 *
 * lookbehind(["a", "b", "c"]);
 * // /(?<=abc)/
 * ```
 */

function lookbehind(sequence) {
  return {
    type: 'lookbehind',
    children: (0, _elements.ensureArray)(sequence),
    encode: encodeLookbehind
  };
}
function encodeLookbehind() {
  return {
    precedence: 'atom',
    pattern: `(?<=${(0, _encoder.encodeSequence)(this.children).pattern})`
  };
}
//# sourceMappingURL=lookbehind.js.map