"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.negativeLookahead = negativeLookahead;
var _encoder = require("../encoder/encoder");
var _elements = require("../utils/elements");
/**
 * Negative lookahead assertion.
 *
 * A negative lookahead assertion is a zero-width assertion that matches a group of characters only if it is not followed by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookahead("a");
 * // /(?=a)/
 *
 * negativeLookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */

function negativeLookahead(sequence) {
  return {
    type: 'negativeLookahead',
    children: (0, _elements.ensureArray)(sequence),
    encode: encodeNegativeLookahead
  };
}
function encodeNegativeLookahead() {
  return {
    precedence: 'atom',
    pattern: `(?!${(0, _encoder.encodeSequence)(this.children).pattern})`
  };
}
//# sourceMappingURL=negative-lookahead.js.map