"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.negativeLookbehind = negativeLookbehind;
var _encoder = require("../encoder/encoder");
var _elements = require("../utils/elements");
/**
 * Negative lookbehind assertion.
 *
 * A negative lookbehind assertion is a zero-width assertion that matches a group of characters only if it is not preceded by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookbehind("a");
 * // /(?<!a)/
 *
 * negativeLookbehind(["a", "b", "c"]);
 * // /(?<!abc)/
 * ```
 */

function negativeLookbehind(sequence) {
  return {
    type: 'negativeLookbehind',
    children: (0, _elements.ensureArray)(sequence),
    encode: encodeNegativeLookbehind
  };
}
function encodeNegativeLookbehind() {
  return {
    precedence: 'atom',
    pattern: `(?<!${(0, _encoder.encodeSequence)(this.children).pattern})`
  };
}
//# sourceMappingURL=negative-lookbehind.js.map