import { encodeSequence } from '../encoder/encoder';
import { ensureArray } from '../utils/elements';

/**
 * Positive lookahead assertion.
 *
 * A positive lookahead assertion is a zero-width assertion that matches a group of characters only if it is followed by a specific group of characters.
 *
 * @example
 * ```ts
 * lookahead("a");
 * // /(?=a)/
 *
 * lookahead(["a", "b", "c"]);
 * // /(?=abc)/
 * ```
 */

export function lookahead(sequence) {
  return {
    type: 'lookahead',
    children: ensureArray(sequence),
    encode: encodeLookahead
  };
}
function encodeLookahead() {
  return {
    precedence: 'atom',
    pattern: `(?=${encodeSequence(this.children).pattern})`
  };
}
//# sourceMappingURL=lookahead.js.map