import { encodeSequence } from '../encoder/encoder';
import { ensureArray } from '../utils/elements';

/**
 * Negative lookbehind assertion.
 *
 * A negative lookbehind assertion is a zero-width assertion that matches a group of characters only if it is not preceded by a specific group of characters.
 *
 * @example
 * ```ts
 * negativeLookbehind("a");
 * // /(?<!a)/
 *
 * negativeLookbehind(["a", "b", "c"]);
 * // /(?<!abc)/
 * ```
 */

export function negativeLookbehind(sequence) {
  return {
    type: 'negativeLookbehind',
    children: ensureArray(sequence),
    encode: encodeNegativeLookbehind
  };
}
function encodeNegativeLookbehind() {
  return {
    precedence: 'atom',
    pattern: `(?<!${encodeSequence(this.children).pattern})`
  };
}
//# sourceMappingURL=negative-lookbehind.js.map